Index: main/waeup.kofa/trunk/src/waeup/kofa/applicants/tests/test_browser.py
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/applicants/tests/test_browser.py	(revision 13363)
+++ main/waeup.kofa/trunk/src/waeup/kofa/applicants/tests/test_browser.py	(revision 13365)
@@ -1392,17 +1392,21 @@
         self.browser.getControl("Submit").click()
         self.assertTrue('No application record found' in self.browser.contents)
-        self.browser.getControl(name="unique_id").value = self.applicant.applicant_id
+        self.browser.getControl(
+          name="unique_id").value = self.applicant.applicant_id
         self.browser.getControl(name="lastname").value = 'nonsense'
         self.browser.getControl("Submit").click()
         self.assertTrue('No application record found' in self.browser.contents)
-        self.browser.getControl(name="unique_id").value = self.applicant.applicant_id
+        self.browser.getControl(
+          name="unique_id").value = self.applicant.applicant_id
         self.browser.getControl(name="lastname").value = 'Lion'
         self.browser.getControl("Submit").click()
         self.assertTrue('Application status of' in self.browser.contents)
-        self.assertTrue('You have not yet submitted your application' in self.browser.contents)
+        self.assertTrue(
+          'You have not yet submitted your application' in self.browser.contents)
         IWorkflowState(self.applicant).setState('admitted')
         self.browser.open('http://localhost/app/applicants/checkstatus')
-        self.browser.getControl(name="unique_id").value = self.applicant.applicant_id
-        # whitespaces are ignored
+        self.browser.getControl(
+          name="unique_id").value = self.applicant.applicant_id
+        # Whitespaces are ignored.
         self.browser.getControl(name="lastname").value = 'Lion'
         self.browser.getControl("Submit").click()
@@ -1411,20 +1415,35 @@
         self.applicant.course_admitted = self.certificate
         self.browser.open('http://localhost/app/applicants/checkstatus')
-        self.browser.getControl(name="unique_id").value = self.applicant.applicant_id
+        self.browser.getControl(
+          name="unique_id").value = self.applicant.applicant_id
         self.browser.getControl(name="lastname").value = 'Lion'
         self.browser.getControl("Submit").click()
         self.assertTrue('Congratulations!' in self.browser.contents)
         self.assertTrue('Unnamed Certificate (CERT1)' in self.browser.contents)
-        self.assertTrue('Department of Unnamed Department (dep1)' in self.browser.contents)
-        self.assertTrue('Faculty of Unnamed Faculty (NA)' in self.browser.contents)
-        # also the reg_number can be used
+        self.assertTrue(
+          'Department of Unnamed Department (dep1)' in self.browser.contents)
+        self.assertTrue(
+          'Faculty of Unnamed Faculty (NA)' in self.browser.contents)
+        # Also the reg_number can be used and page shows student id and password
+        # if applicant is in state created.
+        IWorkflowState(self.applicant).setState('created')
+        self.applicant.student_id = u'my id'
         self.browser.open('http://localhost/app/applicants/checkstatus')
-        self.browser.getControl(name="unique_id").value = self.applicant.reg_number
+        self.browser.getControl(
+          name="unique_id").value = self.applicant.reg_number
         self.browser.getControl(name="lastname").value = 'Lion'
         self.browser.getControl("Submit").click()
         self.assertTrue('Congratulations!' in self.browser.contents)
         self.assertTrue('Unnamed Certificate (CERT1)' in self.browser.contents)
-        self.assertTrue('Department of Unnamed Department (dep1)' in self.browser.contents)
-        self.assertTrue('Faculty of Unnamed Faculty (NA)' in self.browser.contents)
+        self.assertTrue('Department of Unnamed Department (dep1)'
+            in self.browser.contents)
+        self.assertTrue(
+          'Faculty of Unnamed Faculty (NA)' in self.browser.contents)
+        self.assertTrue('user name (= student id) is: <strong>my id</strong>'
+            in self.browser.contents)
+        self.assertTrue(
+          'password is: <strong>%s</strong>' % self.applicant.application_number
+          in self.browser.contents)
+        
 
 class ApplicantsExportTests(ApplicantsFullSetup, FunctionalAsyncTestCase):
